package map2esql.wizards;

import org.eclipse.jface.wizard.WizardPage;
import org.eclipse.swt.widgets.*;
import org.eclipse.swt.events.SelectionEvent;
import org.eclipse.swt.events.SelectionListener;
import org.eclipse.swt.layout.*;
import org.eclipse.swt.SWT;
import org.eclipse.jface.viewers.*;

public class Map2esqlWizardPage extends WizardPage {
	private Text containerText;
	private Text fileText;
	private ISelection selection;
	private String				outdomain		= "MRM"; // Default to MRM
	private String 				indomain 		= "MRM"; // Default to MRM
	private boolean				InBRef		= false;
	private boolean				OutBRef		= false; 
		
	/**
	 * Constructor for Map2esqlWizardPage.
	 * @param pageName
	 */
	public Map2esqlWizardPage(ISelection selection) {
		super("wizardPage");
		setTitle("ESQL Preferences Wizard");
		setDescription("This wizard takes a Mapping File and generates ESQL according to the specified preferences.");
		this.selection = selection;
	}
	
	/**
	 * @see IDialogPage#createControl(Composite)
	 */
	public void createControl(Composite parent) {
		
		Composite composite = new Composite(parent, SWT.NULL);
		setControl(composite);
		GridLayout layout = new GridLayout();
		composite.setLayout(layout);
		layout.numColumns = 4;
		layout.verticalSpacing = 5;
		
    	Label inrefRequiredLabel = new Label(composite, SWT.NONE );
    	inrefRequiredLabel.setText("Use an ESQL REFERENCE for Body of InputRoot");
    	final Button inrefRequiredCheckbox = new Button(composite, SWT.CHECK);    	
    	Map2esqlWizard.setInBRef(false);
    	inrefRequiredCheckbox.addSelectionListener(new SelectionListener() {
			public void widgetSelected(SelectionEvent e) { 
				if (InBRef) {Map2esqlWizard.setInBRef(false);}
				else {Map2esqlWizard.setInBRef(true);}
				//System.out.println("Check box was checked ... value is now "+InBRef);					
			}
			public void widgetDefaultSelected(SelectionEvent e) {
			}
			
	      });
   	    	
    	Label outrefRequiredLabel = new Label(composite, SWT.NONE );
    	outrefRequiredLabel.setText("Use an ESQL REFERENCE for Body of OutputRoot"); 
    	final Button outrefRequiredCheckbox = new Button(composite, SWT.CHECK);   	
    	Map2esqlWizard.setOutBRef(false);
    	outrefRequiredCheckbox.addSelectionListener(new SelectionListener() {
			public void widgetSelected(SelectionEvent e) { 
				if (OutBRef) {Map2esqlWizard.setOutBRef(false);}
				else {Map2esqlWizard.setOutBRef(true);}
				//System.out.println("Check box was checked ... value is now "+OutBRef);									
			}
			public void widgetDefaultSelected(SelectionEvent e) {
			}
			
	      });

   		Label indomainLabel = new Label(composite, SWT.NONE );
		indomainLabel.setText("Select Input Message Domain:");		
		final Combo indomainDropDown = new Combo(composite, SWT.DROP_DOWN | SWT.READ_ONLY | SWT.BORDER);
		Map2esqlWizard.setIndomain("MRM"); // Set MRM as default
		indomainDropDown.add("MRM");	
		indomainDropDown.add("XMLNSC");
		indomainDropDown.add("XMLNS");
		indomainDropDown.add("XML");
		indomainDropDown.add("SOAP");
		indomainDropDown.setText("MRM");
		indomainDropDown.setEnabled(true);
    	indomainDropDown.addSelectionListener(new SelectionListener() {
			public void widgetSelected(SelectionEvent e) {
				if (indomainDropDown.getSelectionIndex() == 0) {Map2esqlWizard.setIndomain("MRM");}	 
				if (indomainDropDown.getSelectionIndex() == 1) {Map2esqlWizard.setIndomain("XMLNSC");}
				if (indomainDropDown.getSelectionIndex() == 2) {Map2esqlWizard.setIndomain("XMLNS");}
				if (indomainDropDown.getSelectionIndex() == 3) {Map2esqlWizard.setIndomain("XML");}	 
				if (indomainDropDown.getSelectionIndex() == 4) {Map2esqlWizard.setIndomain("SOAP");}
			}
			public void widgetDefaultSelected(SelectionEvent e) {
			}
			
	      });		  	
    	
    	Label outdomainLabel = new Label(composite, SWT.NONE );
		outdomainLabel.setText("Select Output Message Domain:");		
		final Combo outdomainDropDown = new Combo(composite, SWT.DROP_DOWN | SWT.READ_ONLY | SWT.BORDER);
		Map2esqlWizard.setOutdomain("MRM"); // Set MRM as default
		outdomainDropDown.add("MRM");	
		outdomainDropDown.add("XMLNSC");
		outdomainDropDown.add("XMLNS");
		outdomainDropDown.add("XML");
		outdomainDropDown.add("SOAP");
		outdomainDropDown.setText("MRM");
		outdomainDropDown.setEnabled(true);
    	outdomainDropDown.addSelectionListener(new SelectionListener() {
			public void widgetSelected(SelectionEvent e) { 
				if (outdomainDropDown.getSelectionIndex() == 0) {Map2esqlWizard.setOutdomain("MRM");}	 
				if (outdomainDropDown.getSelectionIndex() == 1) {Map2esqlWizard.setOutdomain("XMLNSC");}
				if (outdomainDropDown.getSelectionIndex() == 2) {Map2esqlWizard.setOutdomain("XMLNS");}
				if (outdomainDropDown.getSelectionIndex() == 3) {Map2esqlWizard.setOutdomain("XML");}
				if (outdomainDropDown.getSelectionIndex() == 4) {Map2esqlWizard.setOutdomain("SOAP");}
			}
			public void widgetDefaultSelected(SelectionEvent e) {
			}
			
	      });
    	
    	setPageComplete(true);
	
	}
		
}